// ************************************************** Common: Begin **************************************************
// const COPYRIGHT_YEAR = 1937
// TODO: the actual COPYRIGHT_YEAR has to be inserted somehow (e.g. by the postprocessing script)

const onresize = (dom_elem, callback) => {
  const resizeObserver = new ResizeObserver(() => callback() );
  resizeObserver.observe(dom_elem);
};

const AANALYTICS_SCRIPT_SOURCE = "//assets.adobedtm.com/launch-EN3504a9f210b14bc28b773c8d8c5a022d.min.js"

const ON_RS_DOMAIN = window.location.hostname.endsWith("rohde-schwarz.com");

function addTrackingScript() {
    let js = document.createElement("script");
    js.src = AANALYTICS_SCRIPT_SOURCE;
    js.async = true;
    document.querySelector("head").append(js);    
}

function redirectLogoLink() {
    var logoWrapper = document.querySelector("div.logo-wrapper");
    logoWrapper.querySelector("a.logo").setAttribute("href", "https://www.rohde-schwarz.com");
}

function fixSearchEncoding() {
	var searchInputField = document.querySelector('form.search input');
	var searchSubmitDiv = document.querySelector("div.search-submit");
	searchInputField.addEventListener("keypress", function(e) {
		if (e.keyCode===13) {
			encodeInputField(searchInputField);
		}
	}, true);
	searchSubmitDiv.addEventListener("click", function() {
		encodeInputField(searchInputField);
	}, true);
}

function encodeInputField(inputField) {
	if(inputField.value!="") {
		inputField.style.visibility='hidden';
		inputField.value = encodeURI(inputField.value);
	}
}

function decodeInputField(inputField) {
	if(inputField.value!="") {
		inputField.style.visibility='hidden';
		inputField.value = decodeURI(inputField.value);
		inputField.style.visibility='visible';
	}
}

function preserveSidenavWidth() {
    if (typeof(Storage) !== "undefined") {
        var sidenavWrapperDiv = document.querySelector('div.sidenav-wrapper');
        if(sessionStorage.getItem("sidenavWrapperDiv.width")) {
            sidenavWrapperDiv.style.width = sessionStorage.getItem("sidenavWrapperDiv.width");
        }
        onresize(sidenavWrapperDiv, function () {
            sessionStorage.setItem("sidenavWrapperDiv.width", sidenavWrapperDiv.style.width);
        })
    }
}

function insertWebFooterAfter(element) {
    var cy = (typeof COPYRIGHT_YEAR !== 'undefined'? COPYRIGHT_YEAR: new Date().getFullYear());
    element.insertAdjacentHTML('beforeend',
    '<div class="web-footer"><hr/>' +
    '<table><colgroup><col/><col/></colgroup><tbody><tr>' +
    '<td><a href="https://www.rohde-schwarz.com/imprint\">Imprint</a> | <a href="https://www.rohde-schwarz.com/statement-of-privacy">Statement of privacy</a> | <a href="https://www.rohde-schwarz.com/terms-of-website-use">Terms of website use</a></td>' +
    '<td>&#169; ' + cy + ' ROHDE &amp; SCHWARZ</td></tr></tbody></table>');
}
// ************************************************** Common: End   **************************************************

window.addEventListener('load', function () {
	fixSearchEncoding();
	var searchInputField = document.querySelector('form.search input');
	var searchFilterContentDiv = document.querySelector("div.search-filter-content");
	searchFilterContentDiv.addEventListener("click", function() {
		encodeInputField(searchInputField);
	}, true);
	preserveSidenavWidth();
    if (ON_RS_DOMAIN) {
        redirectLogoLink();
        insertWebFooterAfter(document.querySelector(".body-container"));
    }
    const querySpan = document.querySelector('#results-heading > span.query');
    /* We have to wait until Flare has compiled the search results, i.e. until querySpan is updated */
    const onQuerySpanChanged = function (mutationsList, observer) {
		let searchInputField = document.querySelector('form.search input');
		decodeInputField(searchInputField);
        let searchPhrase = searchInputField.value;
        let selectedFilterItem = getSelectedFilterItem();
        let filtered = (isSearchFilterVisible() && selectedFilterItem[0] > 0);
        let filter = (isSearchFilterVisible() ? selectedFilterItem[1]: "-");
		let qstc = querySpan.textContent;
        querySpan.textContent = qstc.substring(1, qstc.length-1);
		if (filtered) {
			querySpan.insertAdjacentHTML('afterend', ' with filter <span class="queryfilter">' + filter + '</span>');
		}
        let ppos = window.location.href.indexOf("&p=");
        let page = (ppos >= 0 ? window.location.href.substring(ppos + 3): 1);
        console.log("Filter: " + filter);
        console.log("Search phrase: " + searchPhrase);
        console.log("Page: " + page);
        // digitalData is inserted by the postprocessing script
        if (ON_RS_DOMAIN && typeof digitalData !== 'undefined') {
            completeDigitalData(filter, searchPhrase, page);
            addTrackingScript();
        }
        observer.disconnect();
    };
    const queryObserver = new MutationObserver(onQuerySpanChanged);
    queryObserver.observe(querySpan, {
        characterData: true, childList: true
    });
})

function isSearchFilterVisible() {
    let searchFilterWrapper = document.querySelector('div.search-filter-wrapper');
    return (window.getComputedStyle(searchFilterWrapper).display == "block");
}

function getSelectedFilterItem() {
    let searchPlaceholderText = document.querySelector('form.search input').getAttribute('placeholder');
    /* console.log("Search placeholder text: " + searchPlaceholderText); */
    let filterItems = document.querySelectorAll('div.search-filter-content > ul > li');
    for (let pos = 1; pos < filterItems.length; pos++) {
        let filterItemText = filterItems[pos].textContent;
        /* endsWith (ECMA6) not available in IE and outdated browser widget ... */
        if (searchPlaceholderText.substring(searchPlaceholderText.length - filterItemText.length) == filterItemText) {
            return[pos, filterItemText];
        }
    }
    return[0, filterItems[0].textContent];
}

function completeDigitalData(filter, searchPhrase, pageNo) {
    // console.log("navLevel_3: " + digitalData[ "page"][ "navLevel_3"]);
    digitalData[ "page"][ "navLevel_4"] = "Filter text: " + filter.replace('|', '∣');
    // console.log("navLevel_4: " + digitalData[ "page"][ "navLevel_4"]);
    digitalData[ "page"][ "navLevel_5"] = "Search phrase: " + searchPhrase.replace("|", '∣');
    // console.log("navLevel_5: " + digitalData[ "page"][ "navLevel_5"]);
    digitalData[ "page"][ "navLevel_6"] = "Result page: " + pageNo;
    // console.log("navLevel_6: " + digitalData[ "page"][ "navLevel_6"]);
}
